@@ -58,10 +58,10 @@
 ##'   }
 ##' @references
 ##' \itemize{
-##'   \item Hornung, R. (2022). "Diversity forests: Using split sampling to enable innovative complex split procedures in random forests". SN Computer Science 3(2):1, <\doi{10.1007/s42979-021-00920-1}>.
-##'   \item Wright, M. N. & Ziegler, A. (2017). "ranger: A fast Implementation of Random Forests for High Dimensional Data in C++ and R". J Stat Softw 77:1-17, <\doi{10.18637/jss.v077.i01}>.
-##'   \item Wager, S., Hastie T., & Efron, B. (2014). "Confidence Intervals for Random Forests: The Jackknife and the Infinitesimal Jackknife". J Mach Learn Res 15:1625-1651.
-##'   \item Meinshausen (2006). "Quantile Regression Forests". J Mach Learn Res 7:983-999.
+##'   \item Hornung, R. (2022). Diversity forests: Using split sampling to enable innovative complex split procedures in random forests. SN Computer Science 3(2):1, <\doi{10.1007/s42979-021-00920-1}>.
+##'   \item Wright, M. N., Ziegler, A. (2017). ranger: A fast Implementation of Random Forests for High Dimensional Data in C++ and R. Journal of Statistical Software 77:1-17, <\doi{10.18637/jss.v077.i01}>.
+##'   \item Wager, S., Hastie T., & Efron, B. (2014). Confidence Intervals for Random Forests: The Jackknife and the Infinitesimal Jackknife. Journal of Machine Learning Research 15:1625-1651.
+##'   \item Meinshausen (2006). Quantile Regression Forests. Journal of Machine Learning Research 7:983-999.
 ##'   }
 ##' @seealso \code{\link{divfor}}
 ##' @author Marvin N. Wright
@@ -149,7 +149,7 @@ predict.divfor.forest <- function(object, data, predict.all = FALSE,
   }
 
   ## Check forest argument
-  if (class(object) != "divfor.forest") {
+  if (!inherits(object, "divfor.forest")) {
     stop("Error: Invalid class of input object.")
   } else {
     forest <- object
